@@ -361,7 +361,7 @@ def edit_message_caption(token, caption, chat_id=None, message_id=None, inline_m
     return _make_request(token, method_url, params=payload)
 
 
-def edit_message_replay_markup(token, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
+def edit_message_reply_markup(token, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
     method_url = r'editMessageReplyMarkup'
     payload = {}
     if chat_id:
@@ -404,16 +404,6 @@ def answer_inline_query(token, inline_query_id, results, cache_time=None, is_per
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def answer_callback_query(token, callback_query_id, text=None, show_alert=None):
-    method_url = 'answerCallbackQuery'
-    payload = {'callback_query_id': callback_query_id}
-    if text:
-        payload['text'] = text
-    if show_alert:
-        payload['show_alert'] = show_alert
-    return _make_request(token, method_url, params=payload, method='post')
-
-
 def _convert_inline_results(results):
     ret = ''
     for r in results:
